@@ -3,6 +3,8 @@
 
 #include <QtGui>
 #include <QMainWindow>
+#include <QFile>
+#include <QTextStream>
 #include "label.h"
 
 
@@ -35,6 +37,8 @@ private:
 private slots:
     void setType(int x, int y);
     void on_btnClose_pressed();
+    void on_btnSave_pressed();
+    void on_btnClear_pressed();
 };
 
 #endif // MAINWINDOW_H
